==> arquillian-parent-1.1.13.Final-source-release.zip: arquillian-parent-1.1.13.Final/testenrichers/cdi/src/main/java/org/jboss/arquillian/testenricher/cdi/container/CDIExtension.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2014 Red Hat Inc. and/or its affiliates and other contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.arquillian.testenricher.cdi.container;

import javax.enterprise.event.Observes;
import javax.enterprise.inject.spi.BeanManager;
import javax.enterprise.inject.spi.BeforeBeanDiscovery;
import javax.enterprise.inject.spi.BeforeShutdown;
import javax.enterprise.inject.spi.Extension;

public class CDIExtension implements Extension
{
   private static BeanManager beanManager;

   void beforeBeanDiscovery(@Observes BeforeBeanDiscovery beforeBeanDiscovery, BeanManager beanManager)
   {
      setBeanManager(beanManager);
   }

   void beforeShutdown(@Observes BeforeShutdown beforeShutdown)
   {
      setBeanManager(null);
   }

   public static BeanManager getBeanManager()
   {
      return beanManager;
   }

   private static void setBeanManager(BeanManager beanManager)
   {
      CDIExtension.beanManager = beanManager;
   }
}

==> arquillian-parent-1.2.0.Final-source-release.zip: arquillian-parent-1.2.0.Final/testenrichers/cdi/src/main/java/org/jboss/arquillian/testenricher/cdi/container/CDIExtension.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2014 Red Hat Inc. and/or its affiliates and other contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.arquillian.testenricher.cdi.container;

import javax.enterprise.event.Observes;
import javax.enterprise.inject.spi.BeanManager;
import javax.enterprise.inject.spi.BeforeBeanDiscovery;
import javax.enterprise.inject.spi.BeforeShutdown;
import javax.enterprise.inject.spi.Extension;

public class CDIExtension implements Extension {
    private static BeanManager beanManager;

    public static BeanManager getBeanManager() {
        return beanManager;
    }

    private static void setBeanManager(BeanManager beanManager) {
        CDIExtension.beanManager = beanManager;
    }

    void beforeBeanDiscovery(@Observes BeforeBeanDiscovery beforeBeanDiscovery, BeanManager beanManager) {
        setBeanManager(beanManager);
    }

    void beforeShutdown(@Observes BeforeShutdown beforeShutdown) {
        setBeanManager(null);
    }
}
